@@ -1,4 +1,4 @@
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 
 try:
     from django.conf import settings
@@ -9,9 +9,6 @@ except:
     _LOAD_PACKAGES = False
 
 if _LOAD_PACKAGES:
-    from mixins import (TablesMixin, EditTablesMixin, FilteredListView,
-                        SortFilterMixin, CSVTableMixin)
+    from mixins import TablesMixin, EditTablesMixin, FilteredListView
     from column import ColumnURL, Column, DictColumn, FieldColumn
-    from filters import (SortChoice, SortChoiceField, SortChoiceFilter,
-                         BaseSortableFilterSet)
     from table import Table, EditTable
